import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1
import QtGraphicalEffects 1.0


Page {
    id: root
    title: i18n.tr("Themes")
    visible: false
    
    property var selectedColor: standardTheme.foreground

    Column {
	anchors.fill: parent

	ListItem.ValueSelector {
            text: "Main theme"
            values: ["Standard"]
	}
	ListItem.ValueSelector {
            text: "Eye theme"
            values: ["Standard"]
	}
	ListItem.Empty {
            height: units.gu(20)
	    UbuntuShape {
		id: backgroundColorBorder
		width: backgroundColor.width + units.gu(0.5)
		color: "black"
		anchors.centerIn: backgroundColor
		radius: "medium"
		visible: selectedColor === standardTheme.background
	    }	    
	    UbuntuShape {
		id: backgroundColor
		anchors.left: parent.left
		anchors.top: parent.top
		anchors.leftMargin: units.gu(3)
		anchors.topMargin: units.gu(3)
		color: standardTheme.background
		radius: "medium"
		MouseArea {
		    anchors.fill: parent
		    onClicked: { 
			root.selectedColor = standardTheme.background

			redSlider.dragged.disconnect(redSlider.changeColor)    
			redSlider.value = root.selectedColor.r * 255
			redSlider.dragged.connect(redSlider.changeColor)    

			greenSlider.dragged.disconnect(greenSlider.changeColor)    
			greenSlider.value = root.selectedColor.g * 255
			greenSlider.dragged.connect(greenSlider.changeColor)    

			blueSlider.dragged.disconnect(blueSlider.changeColor)    
			blueSlider.value = root.selectedColor.b * 255
			blueSlider.dragged.connect(blueSlider.changeColor)    

		    }
		}
	    }
	    UbuntuShape {
		id: foregroundColorBorder
		width: foregroundColor.width + units.gu(0.5)
		color: "black"
		anchors.centerIn: foregroundColor
		radius: "medium"
		visible: selectedColor === standardTheme.foreground
	    }	    
	    UbuntuShape {
		id: foregroundColor
		anchors.left: parent.left
		anchors.top: parent.top
		anchors.leftMargin: units.gu(8)
		anchors.topMargin: units.gu(8)
		color: standardTheme.foreground
		radius: "medium"
		MouseArea {
		    anchors.fill: parent
		    onClicked: { 
			root.selectedColor = standardTheme.foreground 

			redSlider.dragged.disconnect(redSlider.changeColor)    
			redSlider.value = root.selectedColor.r * 255
			redSlider.dragged.connect(redSlider.changeColor)    

			greenSlider.dragged.disconnect(greenSlider.changeColor)    
			greenSlider.value = root.selectedColor.g * 255
			greenSlider.dragged.connect(greenSlider.changeColor)    

			blueSlider.dragged.disconnect(blueSlider.changeColor)    
			blueSlider.value = root.selectedColor.b * 255
			blueSlider.dragged.connect(blueSlider.changeColor)
		    }
		}
	    }
	    Column {
		id: sliders
		width: parent.width - units.gu(20)
		anchors.topMargin: units.gu(1)
		anchors.right: parent.right
		anchors.top: parent.top
		spacing: units.gu(1)

		Row {
		    spacing: units.gu(1)
		    Label {
			text: i18n.tr("Red")
			width: units.gu(4)
			fontSize: "medium"
			anchors.verticalCenter: parent.verticalCenter
			color: "red"
		    }
		    Slider {
			id: redSlider
			width: sliders.width - units.gu(5)
			minimumValue: 0
			maximumValue: 255
			value: 0.0
			live: true

			// it seems impossible to unbind properties.
			// I need to change the binding slider.value -> theme.color1 to slider-value -> theme.color2
			// but at the same time, I need to update the slider.value to theme.color2
			// To achieve this without any strange sideeffects, I need to 
			// 1) unbind
		        // 2) set new value
		        // 3) bind value to new color
	                // this seems only possible with signals, because they can be disconnected and connected

			signal dragged
			function changeColor () {
			    root.selectedColor.r = value / 255
			    qrcanvastext.requestQrCodePaint(qrcanvastext.text)
			}
			onValueChanged: dragged()
			Component.onCompleted: {
			    // this connection is disconnected and re-connected when changing the color target
			    dragged.connect(changeColor)
			}
		    }
		}
		Row {
		    spacing: units.gu(1)
		    Label {
			text: i18n.tr("Green")
			width: units.gu(4)
			fontSize: "medium"
			anchors.verticalCenter: parent.verticalCenter
			color: "green"
		    }

		    Slider {
			id: greenSlider
			width: sliders.width - units.gu(5)
			minimumValue: 0
			maximumValue: 255
			value: 0.0
			live: true
			signal dragged
			function changeColor () {
			    root.selectedColor.g = value / 255
			    qrcanvastext.requestQrCodePaint(qrcanvastext.text)
			}
			onValueChanged: dragged()
			Component.onCompleted: {
			    // this connection is disconnected and re-connected when changing the color target
			    dragged.connect(changeColor)
			}
		    }
		}
		Row {
		    spacing: units.gu(1)
		    Label {
			text: i18n.tr("Blue")
			width: units.gu(4)
			fontSize: "medium"
			anchors.verticalCenter: parent.verticalCenter
			color: "blue"
		    }
		    Slider {
			id: blueSlider
			width: sliders.width - units.gu(5)
			minimumValue: 0
			maximumValue: 255
			value: 0.0
			live: true
			signal dragged
			function changeColor () {
			    root.selectedColor.b = value / 255
			    qrcanvastext.requestQrCodePaint(qrcanvastext.text)
			}
			onValueChanged: dragged()
			Component.onCompleted: {
			    // this connection is disconnected and re-connected when changing the color target
			    dragged.connect(changeColor)
			}
		    }
		}
	    }
	}
	ListItem.SingleControl {
	    height: units.gu(28)
            QrCodeCanvas {
		id: qrcanvastext
		anchors.centerIn: parent
		width: units.gu(24)
		height: units.gu(24)
            }
	}
    }
}